TlvObject class

A single TLV (Tag-Length-Value) node in an EMV data object.

Constructors

TlvObject({required int tag, required List<int> value, List<TlvObject> children = const []})
const

Properties

children List<TlvObject>
Recursively parsed children (populated when this is a constructed tag).
final
hashCode int
The hash code for this object.
no setterinherited
isConstructed bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag int
final
tagHex String
no setter
value List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited